% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_osw.R
\name{getTransitions}
\alias{getTransitions}
\title{Get transitions from all feature files}
\usage{
getTransitions(
  fileInfo,
  maxFdrQuery = 0.05,
  runType = "DIA_Proteomics",
  applyFun = lapply
)
}
\arguments{
\item{fileInfo}{(data-frame) output of \code{\link{getRunNames}} function.}

\item{maxFdrQuery}{(numeric) a numeric value between 0 and 1. It is used to filter features from osw file which have SCORE_MS2.QVALUE less than itself.}

\item{runType}{(char) yhis must be one of the strings "DIA_Proteomics", "DIA_Metabolomics".}

\item{applyFun}{(function) value must be either lapply or BiocParallel::bplapply.}
}
\value{
(list of dataframes) each dataframe has following columns:
\item{transition_group_id}{(integer) a unique id for each precursor.}
\item{RT}{(numeric) retention time as in FEATURE.EXP_RT of osw files.}
\item{intensity}{(list) of peak intensities as in FEATURE_TRANSITION.AREA_INTENSITY of osw files.}
\item{leftWidth}{(numeric) as in FEATURE.LEFT_WIDTH of osw files.}
\item{rightWidth}{(numeric) as in FEATURE.RIGHT_WIDTH of osw files.}
\item{peak_group_rank}{(integer) rank of each feature associated with transition_group_id.}
\item{m_score}{(numeric) q-value of each feature associated with transition_group_id.}
}
\description{
Get a list of data-frame of OpenSwath features that contains retention time, intensities, boundaries etc.
}
\examples{
dataPath <- system.file("extdata", package = "DIAlignR")
fileInfo <- getRunNames(dataPath = dataPath)
transitions <- getTransitions(fileInfo, maxFdrQuery = 1.00, runType = "DIA_Proteomics")
dim(transitions[[2]]) # 938  8
}
\seealso{
\code{\link{getRunNames}, \link{fetchTransitionsFromRun}}
}
\author{
Shubham Gupta, \email{shubh.gupta@mail.utoronto.ca}

ORCID: 0000-0003-3500-8152

License: (c) Author (2020) + GPL-3
Date: 2020-11-15
}
