% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chromatogram_manip.R
\name{smoothSingleXIC}
\alias{smoothSingleXIC}
\title{Smooth chromatogram signal}
\usage{
smoothSingleXIC(
  chromatogram,
  type,
  samplingTime = NULL,
  kernelLen = NULL,
  polyOrd = NULL
)
}
\arguments{
\item{chromatogram}{(dataframe) A dataframe of two columns. First column must always be
monotonically increasing.}

\item{type}{(char) must be either sgolay, boxcar, gaussian, loess or none.}

\item{samplingTime}{(numeric) Time difference between neighboring points.}

\item{kernelLen}{(integer) Number of data-points to consider in the kernel.}

\item{polyOrd}{(integer) Order of the polynomial to be fit in the kernel.}
}
\value{
A dataframe with two columns.
}
\description{
Smoothing methods are Savitzky-Golay, Boxcar, Gaussian kernel and LOESS. Savitzky-Golay smoothing
is good at preserving peak-shape compared to gaussian and boxcar smoothing. However, it assumes
equidistant points that fortunately is the case for DIA data. This requires a quadratic memory
to store the fit and slower than other smoothing methods.
}
\details{
Gaussian smoothing uses a gaussian function whose bandwidth is scaled by 0.3706505 to have
quartiles at +/- 0.25*bandwidth. The point selection cut-off is also hard at 0.3706505*4*bandwidth.

qnorm(0.75, sd = 0.3706505)

The definition of C_ksmooth can be found using
getAnywhere('C_ksmooth')
stats:::C_ksmooth
}
\examples{
data("XIC_QFNNTDIVLLEDFQK_3_DIAlignR")
chrom <- XIC_QFNNTDIVLLEDFQK_3_DIAlignR[["hroest_K120808_Strep10\%PlasmaBiolRepl1_R03_SW_filt"]][["4618"]][[1]]
\dontrun{
newChrom <- smoothSingleXIC(chrom, type = "sgolay", samplingTime = 3.42, kernelLen = 9,
 polyOrd = 3)
}
}
\seealso{
\url{https://terpconnect.umd.edu/~toh/spectrum/Smoothing.html},
 \url{https://rafalab.github.io/dsbook/smoothing.html},
 \url{https://github.com/SurajGupta/r-source/blob/master/src/library/stats/src/ksmooth.c}
}
\author{
Shubham Gupta, \email{shubh.gupta@mail.utoronto.ca}

ORCID: 0000-0003-3500-8152

License: (c) Author (2020) + GPL3
Date: 2020-02-21
}
